# QiYu-api

[![Black Format Check](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/black-format.yml/badge.svg)](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/black-format.yml)
[![CodeQL](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/codeql-analysis.yml)
[![Poetry Publish](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/poetry_pypi.yml/badge.svg)](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/poetry_pypi.yml)
[![Pylama Lint](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/pylama-lint.yml/badge.svg)](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/pylama-lint.yml)
[![pytest](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/pytest.yml/badge.svg)](https://github.com/QiYuTechDev/qiyu-api/actions/workflows/pytest.yml)

![PyPI - Version](https://img.shields.io/pypi/v/qiyu-api)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/qiyu-api)
![PyPI - Downloads](https://img.shields.io/pypi/dm/qiyu-api)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/qiyu-api)
![GitHub repo size](https://img.shields.io/github/repo-size/qiyutechdev/qiyu-api)
![Lines of code](https://img.shields.io/tokei/lines/github/qiyutechdev/qiyu-api)

奇遇科技 Python API 集合

## 当前已经合并

* ztk_api
* mob_api
* apns_sdk_py
* qiyu-api
* ali_sms_api
* dtk_api
